TemplateUtils class

Constructors

TemplateUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

capitalize(String s) String
Capitalize first letter
fileToRoute(String filePath) String
Extract route path from file path e.g., "lib/pages/profile/detail.dart" -> "/profile/detail"
formatDate(DateTime date) String
Format a date for display
formatDateTime(DateTime date) String
Format a datetime for display
generateId() String
Generate a unique identifier
toCamelCase(String s) String
Convert a string to camelCase
toKebabCase(String s) String
Convert a string to kebab-case
toPascalCase(String s) String
Convert a string to PascalCase
toSnakeCase(String s) String
Convert a string to snake_case